import React, { Component, useState, useCallback, createContext, useContext, useMemo, useRef, } from "react";
class ErrorBoundary extends Component {
    displayName = "ReactUseErrorBoundary";
    componentDidCatch(...args) {
        this.setState({});
        this.props.onError(...args);
    }
    render() {
        return this.props.children;
    }
}
const noop = () => false;
const errorBoundaryContext = createContext({
    componentDidCatch: { current: undefined },
    error: false,
    setError: noop,
});
export const ErrorBoundaryContext = ({ children }) => {
    const [error, setError] = useState(false);
    const componentDidCatch = useRef();
    const ctx = useMemo(() => ({
        componentDidCatch,
        error,
        setError,
    }), [error]);
    return (React.createElement(errorBoundaryContext.Provider, { value: ctx },
        React.createElement(ErrorBoundary, { error: error, onError: (...args) => {
                setError(true);
                componentDidCatch.current?.(...args);
            } }, children)));
};
ErrorBoundaryContext.displayName = "ReactUseErrorBoundaryContext";
export function withErrorBoundary(WrappedComponent) {
    return (props) => (React.createElement(ErrorBoundaryContext, null,
        React.createElement(WrappedComponent, { key: "WrappedComponent", ...props })));
}
export function useErrorBoundary(componentDidCatch) {
    const ctx = useContext(errorBoundaryContext);
    ctx.componentDidCatch.current = componentDidCatch;
    const resetError = useCallback(() => {
        ctx.setError(false);
    }, []);
    return [ctx.error, resetError];
}
